import { Database } from "https://deno.land/x/mongo@v0.31.2/mod.ts";
import UserRouter from "../routers/UserRouter.ts";
import ImageRouter from "./ImageRouter.ts";
import AppRouter from "./AppRouter.ts";
import RestResponse from "../server/RestResponse.ts";
import { rest, route } from "../server/decorators.ts";
import User from "../models/User.ts";
import Image from "../models/Image.ts";
import { stream } from "../utils/utils.ts";

export class RootRouter extends AppRouter {
    @route('users/*') users;
    @route('images/*') images;

    @rest('*', '*')
    default() {
        return new RestResponse().body(stream('Page not found :/')).status(404);
    }

    constructor(salt: string, db: Database) {
        super();

        const users = db.collection<User>('users');
        const images = db.collection<Image>('images');

        this.users = new UserRouter(salt, users);
        this.images = new ImageRouter(images, users);
    }
}
